@@ -2,10 +2,12 @@ package Contemporary::Perl;
 
 use strict;
 use warnings;
-use true;
+use true ();
 
 sub import {
     strict->import();
     warnings->import();
     true->import();
 }
+
+1;
